import './annotations/all';
import './templating/all';
import './plugins/all';
import './dashboard';
import './playlist/all';
import './panel/all';
import './org/all';
import './admin';
import './alerting/NotificationsEditCtrl';
import './alerting/NotificationsListCtrl';
import './manage-dashboards';
import './profile/all';
import './datasources/settings/HttpSettingsCtrl';
import './datasources/settings/TlsAuthSettingsCtrl';
